From: Andrew Morton <[EMAIL PROTECTED]>
Date: Wed, 31 Oct 2007 15:43:01 -0700

> > sunhme requires lower MTU to handle 802.1q frames - even though the PCI
> > driver supported VLAN tagging, you cannot do full MTU @ 1500 because the
> > driver doesn't set the card to transfer more the extra bytes for a 802.1q
> > frame at 1500 MTU.

It supports VLAN tagging by accident, the NETIF_F_VLAN_CHALLENGED
flag should be set both in the PCI and non-PCI cases.

Jeff, please apply, thanks:

[SUNHME]: Fix missing NETIF_F_VLAN_CHALLENGED on PCI happy meals.

No HME parts can do VLANs correctly.

Signed-off-by: David S. Miller <[EMAIL PROTECTED]>

diff --git a/drivers/net/sunhme.c b/drivers/net/sunhme.c
index 120c8af..c20a3bd 100644
--- a/drivers/net/sunhme.c
+++ b/drivers/net/sunhme.c
@@ -3143,8 +3143,8 @@ static int __devinit happy_meal_pci_probe(struct pci_dev 
*pdev,
        dev->irq = pdev->irq;
        dev->dma = 0;
 
-       /* Happy Meal can do it all... */
-       dev->features |= NETIF_F_SG | NETIF_F_HW_CSUM;
+       /* Happy Meal can do it all... except VLAN. */
+       dev->features |= NETIF_F_SG | NETIF_F_HW_CSUM | NETIF_F_VLAN_CHALLENGED;
 
 #if defined(CONFIG_SBUS) && defined(CONFIG_PCI)
        /* Hook up PCI register/dma accessors. */
-
To unsubscribe from this list: send the line "unsubscribe netdev" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to